# Copyright 2014 - 2016 Paul Hänsch
#
# This file is part of Confetti.
# 
# Confetti is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# Confetti is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
# 
# You should have received a copy of the GNU Affero General Public License
# along with Confetti.  If not, see <http://www.gnu.org/licenses/>. 

check_gen() {
  [ "$values[GENDER]" = "$1" ] && echo 'selected="selected"'
}
check_a() {
  egrep -q "^${1}.${id}$" "$_DATA/mappings/attendance" && echo 'checked="checked"'
}

n_last="$(printf %s "$values[N]" |sed -rn 's:^([^;]*;){0} *([^;]*).*$:\2:p')"
n_first="$(printf %s "$values[N]" |sed -rn 's:^([^;]*;){1} *([^;]*).*$:\2:p')"
n_middle="$(printf %s "$values[N]" |sed -rn 's:^([^;]*;){2} *([^;]*).*$:\2:p')"
n_pre="$(printf %s "$values[N]" |sed -rn 's:^([^;]*;){3} *([^;]*).*$:\2:p')"
n_post="$(printf %s "$values[N]" |sed -rn 's:^([^;]*;){4} *([^;]*)*$:\2:p')"

hi_company="$(printf %s "${values[X-HEALTH-INSURANCE]}" |cut -d\; -f1)"
hi_number="$(printf %s "${values[X-HEALTH-INSURANCE]}" |cut -d\; -f2)"
hi_status="$(printf %s "${values[X-HEALTH-INSURANCE]}" |cut -d\; -f3)"

SUP_FIELDS=(N NICKNAME GENDER BDAY ADR TEL EMAIL X-HEALTH-INSURANCE X-HEALTH-INSURANCE-NOCONTRIB IMPP URL NOTE X-CLIENT-REFERRAL)

[ -z "$values[UID]" ] && values[UID]="$(uuidgenerator)"

cat <<END_HTML
<form id="$id" class="card" action="?action=update_card" method="POST">
  <input type="hidden" name="card" value="${id}"/>
  <div class="section basic">
    <h3>$(l10n N)</h3>
    <input class="item N" name="3N" placeholder="$(l10n n_pre)" value="$n_pre" />
    <input class="item N" name="1N" placeholder="$(l10n n_first)" value="$n_first" />
    <input class="item N" name="2N" placeholder="$(l10n n_middle)" value="$n_middle" />
    <input class="item N" name="0N" placeholder="$(l10n n_last)" value="$n_last" />
    <input class="item N" name="4N" placeholder="$(l10n n_post)" value="$n_post" />

    <select class="item GENDER" name="GENDER">
      <option value="" disabled="disabled">$(l10n GENDER)</option>
      <option value="female" $(check_gen female)>$(l10n gender_female)</option>
      <option value="male" $(check_gen male)>$(l10n gender_male)</option>
      <option value="other" $(check_gen other)>$(l10n gender_other)</option>
      <option value="none" $(check_gen none)>$(l10n gender_none)</option>
    </select>

    $(for n in NICKNAME NICKNAME{0..10}; do
      echo "${values[$n]:+<input class="item NICKNAME" name="NICKNAME" placeholder="$(l10n NICKNAME)" value="$values[$n]" />}"
    done)

    <h3>$(l10n BDAY)</h3>
    <input class="item BDAY" name="BDAY" value="$values[BDAY]" placeholder="YYYY-MM-DD" />

    $(if [ -n "$values[SOUND]" ]; then
      echo '    <audio controls="controls" class="item SOUND">'
      echo '      <source type="audio/ogg" src="data:audio/ogg;base64,'$values[SOUND]'" />'
      echo '    </audio>'
    fi)
    ${values[PHOTO]:+<img class="item PHOTO" src="data:image/$tags[PHOTO_TYPE];base64,$values[PHOTO]" />}
    ${values[LOGO]:+<img class="item LOGO" src="data:image/$tags[LOGO_TYPE];base64,$values[LOGO]" />}
  </div>

  <div class="section address">
    <h3>$(l10n ADR)</h3>
    <textarea class="item ADR" name="ADR">$values[ADR]</textarea>
    $(for n in ADR{0..10}; do
      echo "${values[$n]:+<textarea class="item ADR" name="ADR">$values[$n]</textarea>}"
    done)
    ${values[URL]:+<h3>$(l10n URL)</h3>}
    $(for n in URL URL{0..10}; do
      echo "${values[$n]:+<input class="item URL" name="URL" value="$values[$n]" />}"
    done)
  </div>

  <div class="section phone">
    <h3>$(l10n TEL)</h3>
    <input class="item TEL" name="TEL" value="$values[TEL]" />
    $(for n in TEL{0..10}; do
      echo "${values[$n]:+<input class="item TEL" name="TEL" value="'$values[$n]'" />}"
    done)
    ${values[EMAIL]:+<h3>$(l10n EMAIL)</h3>}
    $(for n in EMAIL EMAIL{0..10}; do
      echo "${values[$n]:+<input class="item EMAIL" name="EMAIL" value="$values[$n]" />}"
    done)
    ${values[IMPP]:+<h3>$(l10n IMPP)</h3>}
    $(for n in IMPP IMPP{0..10}; do
      echo "${values[$n]:+<input class="item IMPP" name="IMPP" value="$values[$n]" />}"
    done)
  </div>

  <div class="section insurance">
    <h3>$(l10n X-HEALTH-INSURANCE)</h3>
    <input type="radio" name="hi_select" value="list" id="hi_select_list" checked /><label for="hi_select_list">$(l10n hi_from_list)</label><!--
    --><input type="radio" name="hi_select" value="other" id="hi_other"><label for="hi_other">$(l10n hi_other)</label>
    <select class="item" name="hi_company">
      <option value="" disabled="disabled" ${hi_company:-selected}>$(l10n hi_company)</option>
      $(list_hi_companies |while read f; do
        [ "$f" = "$hi_company" ] \
        && printf '<option value="%s" selected>%s</option>' "$f" "$f" \
        || printf '<option value="%s">%s</option>' "$f" "$f"
      done)
    </select>
    <input type="text" name="hi_other" value="$hi_company" placeholder="$(l10n hi_company)" />
    <input name="hi_number" value="$hi_number" placeholder="$(l10n hi_number)" />
    <input name="hi_status" value="$hi_status" placeholder="$(l10n hi_status)" />

  </div>

  <div class="section note">
    <h3>$(l10n NOTE)</h3>
    <textarea class="item NOTE" name="NOTE">$values[NOTE]</textarea>
    $(for n in NOTE{0..10}; do
      echo "${values[$n]:+<textarea class="item NOTE" name="NOTE">$values[$n]</textarea>}"
    done)
    <h3>$(l10n X-CLIENT-REFERRAL)</h3>
    <input class="item X-CLIENT-REFERRAL" name="X-CLIENT-REFERRAL" value="$values[X-CLIENT-REFERRAL]" />
    $(for n in X-CLIENT-REFERRAL{0..10}; do
      echo "${values[$n]:+<input class="item X-CLIENT-REFERRAL" name="X-CLIENT-REFERRAL" value="'$values[$n]'" />}"
    done)
  </div>

  <div class="control">
    <select class="item" name="newfield">
      <option value="" disabled="disabled" selected="selected">$(l10n edit_addfieldtext)</option>
      $(for f in $SUP_FIELDS; do echo "<option value=\"$f\">$(l10n $f)</option>"; done)
    </select
    ><button class="item" type="submit" name="action" value="addfield">$(l10n edit_addfield)</button>
    <button class="item" type="submit" name="action" value="update">$(l10n edit_update)</button>
    <button class="item" type="submit" name="action" value="delete">$(l10n edit_delete)</button>
    <button class="item" type="submit" name="action" value="cancel">$(l10n edit_cancel)</button>
  </div>
  <input type="hidden" name="UID" value="$values[UID]"/>
</form>
END_HTML
